﻿
using System.Collections.Generic;
using Irony.Interpreter;
using Irony.Parsing;

namespace Benchmark_Generator {
  class ExpressionEvaluator {
    public ExpressionGrammar Grammar { get; private set; }
    public Parser Parser { get; private set; }
    public LanguageData Language { get; private set; }
    public LanguageRuntime Runtime { get; private set; }
    public ScriptApp App { get; private set; }
    public IDictionary<string, object> Globals { get { return App.Globals; } }

    public ExpressionEvaluator() : this(new ExpressionGrammar()) { }

    public ExpressionEvaluator(ExpressionGrammar grammar) {
      Grammar = grammar;
      Language = new LanguageData(Grammar);
      Parser = new Parser(Language);
      Runtime = Grammar.CreateRuntime(Language);
      App = new ScriptApp(Runtime);
    }

    public object Evaluate(ParseTree parsedScript) {
      var result = App.Evaluate(parsedScript);
      return result;
    }

    public object Evaluate() {
      return App.Evaluate();
    }

    public void ClearOutput() {
      App.ClearOutputBuffer();
    }

    public string GetOutput() {
      return App.GetOutput();
    }
  }
}
